# player control
PLAY_PAUSE = 1
PREVIOUS = 2
NEXT = 3
SET_POSITION = 4
TUNE = 5

# recording
START_STOP_RECORDING = 10

# zooming
ZOOM_IN = 20
ZOOM_OUT = 21
ZOOM_100 = 22
ZOOM_FIT = 23

# adding
ADD = 30

# force speaker
FORCE_SPEAKER = 40

# other
TAB_SELECTED = 50


